@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,7 +20,7 @@ public:
     Q_REQUIRED_RESULT bool start();
 
     Q_REQUIRED_RESULT QString subject() const;
-    void setSubject(const QString &subject);
+    void setMessageInfoText(const QString &subject);
 
     Q_REQUIRED_RESULT int delay() const;
     void setDelay(int delay);
